@@ -7,8 +7,11 @@ either :mod:`nanoutils` or :mod:`nanoutils.utils`.
 
 """
 
+from typing import List
 from functools import partial
 
+__all__: List[str] = []
+
 
 class PartialPrepend(partial):
     """A :func:`~functools.partial` subclass where the ``*args`` are appended rather than prepended.
